#######################################################
#######################################################
############    COPYRIGHT - DATA SOCIETY   ############
#######################################################
#######################################################

################################
##   WORKING WITH DATA SETS   ##
################################

## NOTE: To run individual pieces of code 
## select the line of code and press ctrl + enter for Windows
## and command + enter for Macs

#==================================================================================

# One of the best features of R is its data sets. Each package comes with preloaded data
# that are excellent for practice. Type in the code below to see the list of data sets that 
# are readily available to you. Make sure you install and load the package where the data 
# set is from in order to access it.

data(package = .packages(all.available = TRUE))

# We'll be working with a population data set, state.x77, from the 'MASS' package

install.packages("MASS")
library(MASS)
View(state.x77)

# 1. What does the "Frost" column mean? Use the '?state.x77' to find out!

?state.x77

# Frost: mean number of days with minimum temperature below freezing (1931–1960) 
# in capital or large city


# 2. What do the first few rows look like?

head(state.x77)
# Population Income Illiteracy Life Exp Murder HS Grad Frost   Area
# Alabama          3615   3624        2.1    69.05   15.1    41.3    20  50708
# Alaska            365   6315        1.5    69.31   11.3    66.7   152 566432
# Arizona          2212   4530        1.8    70.55    7.8    58.1    15 113417
# Arkansas         2110   3378        1.9    70.66   10.1    39.9    65  51945

# 3. What are all the categories in the data set?

names(state.x77)
# NULL

# 4. If you were unable to find the categories, check the class of the data. If it is
# not a data frame, change it into a data frame and save it as state.pop.

class(state.x77)
state.pop = as.data.frame(state.x77)
class(state.pop)

# 5. What are the categories for state.pop?

names(state.pop)

# 6. What is the high school graduation rate for Florida?

state.pop["Florida", "HS Grad"]
state.pop[9, 6]

# [1] 52.6

# 7. How about the life expectancy of Virginia?

state.pop["Virginia", "Life Exp"]
state.pop[46, 4]

# [1] 70.08

# 8. Bind the state.pop data set with the state.region data set and keep the name as 
#    state.pop

state.pop = cbind(state.pop, state.region)
View(state.pop)

# 9. Take out the Frost and Area columns

state.pop[,"Frost"] = NULL
state.pop[,"Area"] = NULL
View(state.pop)

# 10. If a state has a murder rate above 10% and a life expectancy below 70, label it
#     as "Needs Improvement". Otherwise, label it as "Satisfactory". Name this new data
#     "state.health"

state.health = ifelse(state.pop$Murder > 10 & state.pop$"Life Exp" < 70, "Needs Improvement",
                      "Satisfactory")
View(state.health)

# 11. Combine the state.pop data set and the state.health column and call it 
#     state.pop.health

state.pop.health = cbind(state.pop, state.health)
View(state.pop.health)

# 12. Order the data set by state.region, set the decreasing order to false and keep it named as
#     'state.pop.health'

state.pop.health = state.pop.health[order(state.pop.health$state.region, decreasing = F),]
View(state.pop.health)


# Continue to practice these operations until you feel
# comfortable in R. The only way to become truly
# proficient is to spend time coding!